@@ -4,15 +4,15 @@ context("Analyze Time Bins")
 TOL <- 0.0001
 compare_dfs <- function(df1, df2, tol=TOL) {
   stopifnot(all(dim(df1)==dim(df2)))
-  
+
   res <- matrix(nrow = nrow(df1), ncol = ncol(df1))
   for (i in 1:ncol(df1)) {
     col <- colnames(df1)[i]
-    
+
     # Replace NAs with 0
     df1[is.na(df1)] <- 0
     df2[is.na(df2)] <- 0
-    
+
     # check difference between elements
     if (is.numeric(df1[[col]])) {
       res[,i] <- df1[[col]] - df2[[col]]
@@ -25,8 +25,8 @@ compare_dfs <- function(df1, df2, tol=TOL) {
   return(TRUE)
 }
 
-data("word_recognition") 
-data <- make_eyetrackingr_data(word_recognition, 
+data("word_recognition")
+data <- make_eyetrackingr_data(word_recognition,
                                participant_column = "ParticipantName",
                                trial_column = "Trial",
                                time_column = "TimeFromTrialOnset",
@@ -35,25 +35,25 @@ data <- make_eyetrackingr_data(word_recognition,
                                treat_non_aoi_looks_as_missing = TRUE
 )
 # subset to response window post word-onset
-response_window <- subset_by_window(data, 
-                                    window_start_time = 15500, 
-                                    window_end_time = 21000, 
+response_window <- subset_by_window(data,
+                                    window_start_time = 15500,
+                                    window_end_time = 21000,
                                     rezero = FALSE)
 # remove trials with > 25% of trackloss
 response_window_clean <- clean_by_trackloss(data = response_window, trial_prop_thresh = .25)
 # create Target condition column
-response_window_clean$Target <- as.factor( ifelse(test = grepl('(Spoon|Bottle)', response_window_clean$Trial), 
-                                                  yes = 'Inanimate', 
+response_window_clean$Target <- as.factor( ifelse(test = grepl('(Spoon|Bottle)', response_window_clean$Trial),
+                                                  yes = 'Inanimate',
                                                   no  = 'Animate') )
 
 # Within Subjects -----------------------------------------------------------------------------
-df_time_within <- make_time_sequence_data(response_window_clean, 
-                                          time_bin_size = 100, 
-                                          aois = c("Animate"), 
+df_time_within <- make_time_sequence_data(response_window_clean,
+                                          time_bin_size = 100,
+                                          aois = c("Animate"),
                                           predictor_columns = c("Target","Sex"),
                                           summarize_by = "ParticipantName")
 num_time_bins <- length(unique(df_time_within$TimeBin))
-tb_within <- analyze_time_bins(df_time_within, predictor_column = "Target", test = "t.test", 
+tb_within <- analyze_time_bins(df_time_within, predictor_column = "Target", test = "t.test",
                         paired=TRUE, alpha = .05 / num_time_bins)
 #dput(tb_within, file = "tb_output_within_subj.txt")
 tb_within_check <- dget(file = "tb_output_within_subj.txt")
@@ -71,14 +71,15 @@ test_that(desc = "The function analyze_time_bins has correct data (within)", cod
 })
 
 # Between Subjects -----------------------------------------------------------------------------
-df_time_between <- make_time_sequence_data(response_window_clean, 
-                                          time_bin_size = 100, 
-                                          aois = c("Animate"), 
+df_time_between <- make_time_sequence_data(response_window_clean,
+                                          time_bin_size = 100,
+                                          aois = c("Animate"),
                                           predictor_columns = "Sex",
                                           summarize_by = "ParticipantName")
 num_time_bins <- length(unique(df_time_between$TimeBin))
-tb_between <- analyze_time_bins(df_time_between, predictor_column = "Sex", test = "t.test", 
-                               paired=FALSE, alpha = .05 )
+tb_between <- analyze_time_bins(df_time_between, predictor_column = "Sex", test = "t.test",
+                               # paired=FALSE,
+                               alpha = .05 )
 #dput(tb_between, file = "tb_output_between_subj.txt")
 tb_between_check <- dget(file = "tb_output_between_subj.txt")
 
@@ -106,9 +107,9 @@ test_that(desc = "The function analyze_time_bins has correct data (interaction)"
 })
 
 # Intercept Model -----------------------------------------------------------------------------
-df_time_intercept <- make_time_sequence_data(response_window_clean, 
-                                           time_bin_size = 100, 
-                                           aois = c("Animate"), 
+df_time_intercept <- make_time_sequence_data(response_window_clean,
+                                           time_bin_size = 100,
+                                           aois = c("Animate"),
                                            predictor_columns = c("Sex","Target"),
                                            summarize_by = "Trial")
 tb_intercept <- analyze_time_bins(df_time_intercept, predictor_column = "(Intercept)", test = "lmer", alpha=.05,
@@ -116,9 +117,9 @@ tb_intercept <- analyze_time_bins(df_time_intercept, predictor_column = "(Interc
                                   formula = Prop ~ Sex*Target + (1|Trial))
 
 # AOI as Predictor -----------------------------------------------------------------------------
-df_time_maoi <- make_time_sequence_data(response_window_clean, 
-                        time_bin_size = 100, 
-                        aois = c("Animate","Inanimate"), 
+df_time_maoi <- make_time_sequence_data(response_window_clean,
+                        time_bin_size = 100,
+                        aois = c("Animate","Inanimate"),
                         predictor_columns = c("Sex","Target"),
                         summarize_by = "Trial")
 tb_maoi <- analyze_time_bins(df_time_maoi, predictor_column = "(Intercept)", test = "lmer", alpha=.05, p_adjust_method = "holm",
